Module blaxel.models.integration_repository
===========================================

Classes
-------

`IntegrationRepository(id: blaxel.types.Unset | str = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, organization: blaxel.types.Unset | str = <blaxel.types.Unset object>, url: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Integration repository
    
    Attributes:
        id (Union[Unset, str]): Repository ID
        name (Union[Unset, str]): Repository name
        organization (Union[Unset, str]): Repository owner
        url (Union[Unset, str]): Repository URL
    
    Method generated by attrs for class IntegrationRepository.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `id: blaxel.types.Unset | str`
    :

    `name: blaxel.types.Unset | str`
    :

    `organization: blaxel.types.Unset | str`
    :

    `url: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :